@@ -376,6 +376,8 @@ inline bool KFileItemPrivate::cmp(const KFileItemPrivate &item) const
     qDebug() << " local" << (m_bIsLocalUrl == item.m_bIsLocalUrl);
     qDebug() << " mode" << (m_fileMode == item.m_fileMode);
     qDebug() << " perm" << (m_permissions == item.m_permissions);
+    qDebug() << " group" << (m_entry.stringValue(KIO::UDSEntry::UDS_GROUP) == item.m_entry.stringValue(KIO::UDSEntry::UDS_GROUP));
+    qDebug() << " user" << (m_entry.stringValue(KIO::UDSEntry::UDS_USER) == item.m_entry.stringValue(KIO::UDSEntry::UDS_USER));
     qDebug() << " UDS_EXTENDED_ACL" << (m_entry.stringValue( KIO::UDSEntry::UDS_EXTENDED_ACL ) == item.m_entry.stringValue( KIO::UDSEntry::UDS_EXTENDED_ACL ));
     qDebug() << " UDS_ACL_STRING" << (m_entry.stringValue( KIO::UDSEntry::UDS_ACL_STRING ) == item.m_entry.stringValue( KIO::UDSEntry::UDS_ACL_STRING ));
     qDebug() << " UDS_DEFAULT_ACL_STRING" << (m_entry.stringValue( KIO::UDSEntry::UDS_DEFAULT_ACL_STRING ) == item.m_entry.stringValue( KIO::UDSEntry::UDS_DEFAULT_ACL_STRING ));
@@ -391,6 +393,8 @@ inline bool KFileItemPrivate::cmp(const KFileItemPrivate &item) const
             && m_bIsLocalUrl == item.m_bIsLocalUrl
             && m_fileMode == item.m_fileMode
             && m_permissions == item.m_permissions
+            && m_entry.stringValue(KIO::UDSEntry::UDS_GROUP) == item.m_entry.stringValue(KIO::UDSEntry::UDS_GROUP)
+            && m_entry.stringValue(KIO::UDSEntry::UDS_USER) == item.m_entry.stringValue(KIO::UDSEntry::UDS_USER)
             && m_entry.stringValue(KIO::UDSEntry::UDS_EXTENDED_ACL) == item.m_entry.stringValue(KIO::UDSEntry::UDS_EXTENDED_ACL)
             && m_entry.stringValue(KIO::UDSEntry::UDS_ACL_STRING) == item.m_entry.stringValue(KIO::UDSEntry::UDS_ACL_STRING)
             && m_entry.stringValue(KIO::UDSEntry::UDS_DEFAULT_ACL_STRING) == item.m_entry.stringValue(KIO::UDSEntry::UDS_DEFAULT_ACL_STRING)
@@ -413,7 +417,9 @@ inline QString KFileItemPrivate::parsePermissions(mode_t perm) const
 
     static char buffer[12];
 
-    char uxbit, gxbit, oxbit;
+    char uxbit;
+    char gxbit;
+    char oxbit;
 
     if ((perm & (S_IXUSR | S_ISUID)) == (S_IXUSR | S_ISUID)) {
         uxbit = 's';
@@ -496,10 +502,11 @@ void KFileItemPrivate::determineMimeTypeHelper(const QUrl &url) const
     QMimeDatabase db;
     if (m_bSkipMimeTypeFromContent) {
         const QString scheme = url.scheme();
-        if (scheme.startsWith(QLatin1String("http")) || scheme == QLatin1String("mailto"))
+        if (scheme.startsWith(QLatin1String("http")) || scheme == QLatin1String("mailto")) {
             m_mimeType = db.mimeTypeForName(QLatin1String("application/octet-stream"));
-        else
+        } else {
             m_mimeType = db.mimeTypeForFile(url.path(), QMimeDatabase::MatchMode::MatchExtension);
+        }
     } else {
         m_mimeType = db.mimeTypeForUrl(url);
     }
@@ -1088,8 +1095,12 @@ QStringList KFileItem::overlays() const
             names.append(QStringLiteral("emblem-important"));
         }
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 82)
         if (cfg.hasDeviceType()) {
+            QT_WARNING_PUSH
+            QT_WARNING_DISABLE_DEPRECATED
             const QString dev = cfg.readDevice();
+            QT_WARNING_POP
             if (!dev.isEmpty()) {
                 KMountPoint::Ptr mountPoint = KMountPoint::currentMountPoints().findByDevice(dev);
                 if (mountPoint) { // mounted?
@@ -1097,6 +1108,7 @@ QStringList KFileItem::overlays() const
                 }
             }
         }
+#endif
     }
 
     if (isHidden()) {
@@ -1428,6 +1440,20 @@ QUrl KFileItem::mostLocalUrl(bool *local) const
     }
 }
 
+KFileItem::MostLocalUrlResult KFileItem::isMostLocalUrl() const
+{
+    if (!d) {
+        return {QUrl(), false};
+    }
+
+    const QString local_path = localPath();
+    if (!local_path.isEmpty()) {
+        return {QUrl::fromLocalFile(local_path), true};
+    } else {
+        return {d->m_url, d->m_bIsLocalUrl};
+    }
+}
+
 QDataStream &operator<<(QDataStream &s, const KFileItem &a)
 {
     if (a.d) {
@@ -1448,7 +1474,8 @@ QDataStream &operator<<(QDataStream &s, const KFileItem &a)
 QDataStream &operator>>(QDataStream &s, KFileItem &a)
 {
     QUrl url;
-    QString strName, strText;
+    QString strName;
+    QString strText;
 
     s >> url;
     s >> strName;
@@ -1576,13 +1603,12 @@ QUrl KFileItem::targetUrl() const
 
 QMimeType KFileItem::currentMimeType() const
 {
-    if (!d) {
+    if (!d || d->m_url.isEmpty()) {
         return QMimeType();
     }
 
     if (!d->m_mimeType.isValid()) {
         // On-demand fast (but not always accurate) MIME type determination
-        Q_ASSERT(!d->m_url.isEmpty());
         QMimeDatabase db;
         if (isDir()) {
             d->m_mimeType = db.mimeTypeForName(QStringLiteral("inode/directory"));
