@@ -15,10 +15,12 @@
 #ifndef KFILEWIDGET_H
 #define KFILEWIDGET_H
 
-#include "kiofilewidgets_export.h"
 #include "kfile.h"
+#include "kiofilewidgets_export.h"
 #include <QWidget>
 
+#include <memory>
+
 class QUrl;
 class QPushButton;
 class KActionCollection;
@@ -47,35 +49,35 @@ class KIOFILEWIDGETS_EXPORT KFileWidget : public QWidget
     Q_OBJECT
 public:
     /**
-      * Constructs a file selector widget.
-      *
-      * @param startDir This can either be:
-      *         @li An empty URL (QUrl()) to start in the current working directory,
-      *             or the last directory where a file has been selected.
-      *         @li The path or URL of a starting directory.
-      *         @li An initial file name to select, with the starting directory being
-      *             the current working directory or the last directory where a file
-      *             has been selected.
-      *         @li The path or URL of a file, specifying both the starting directory and
-      *             an initially selected file name.
-      *         @li A URL of the form @c kfiledialog:///&lt;keyword&gt; to start in the
-      *             directory last used by a filedialog in the same application that
-      *             specified the same keyword.
-      *         @li A URL of the form @c kfiledialog:///&lt;keyword&gt;/&lt;filename&gt;
-      *             to start in the directory last used by a filedialog in the same
-      *             application that specified the same keyword, and to initially
-      *             select the specified filename.
-      *         @li A URL of the form @c kfiledialog:///&lt;keyword&gt;?global to start
-      *             in the directory last used by a filedialog in any application that
-      *             specified the same keyword.
-      *         @li A URL of the form @c kfiledialog:///&lt;keyword&gt;/&lt;filename&gt;?global
-      *             to start in the directory last used by a filedialog in any
-      *             application that specified the same keyword, and to initially
-      *             select the specified filename.
-      *
-      * @param parent The parent widget of this widget
-      *
-      */
+     * Constructs a file selector widget.
+     *
+     * @param startDir This can either be:
+     *         @li An empty URL (QUrl()) to start in the current working directory,
+     *             or the last directory where a file has been selected.
+     *         @li The path or URL of a starting directory.
+     *         @li An initial file name to select, with the starting directory being
+     *             the current working directory or the last directory where a file
+     *             has been selected.
+     *         @li The path or URL of a file, specifying both the starting directory and
+     *             an initially selected file name.
+     *         @li A URL of the form @c kfiledialog:///&lt;keyword&gt; to start in the
+     *             directory last used by a filedialog in the same application that
+     *             specified the same keyword.
+     *         @li A URL of the form @c kfiledialog:///&lt;keyword&gt;/&lt;filename&gt;
+     *             to start in the directory last used by a filedialog in the same
+     *             application that specified the same keyword, and to initially
+     *             select the specified filename.
+     *         @li A URL of the form @c kfiledialog:///&lt;keyword&gt;?global to start
+     *             in the directory last used by a filedialog in any application that
+     *             specified the same keyword.
+     *         @li A URL of the form @c kfiledialog:///&lt;keyword&gt;/&lt;filename&gt;?global
+     *             to start in the directory last used by a filedialog in any
+     *             application that specified the same keyword, and to initially
+     *             select the specified filename.
+     *
+     * @param parent The parent widget of this widget
+     *
+     */
     explicit KFileWidget(const QUrl &startDir, QWidget *parent = nullptr);
 
     /**
@@ -161,7 +163,7 @@ public:
 
     /**
      * Sets a list of URLs as preselected
-     * 
+     *
      * @see setSelectedUrl
      * @since 5.75
      */
@@ -280,8 +282,7 @@ public:
      *
      * Do not use in conjunction with setFilter()
      */
-    void setMimeFilter(const QStringList &types,
-                       const QString &defaultType = QString());
+    void setMimeFilter(const QStringList &types, const QString &defaultType = QString());
 
     /**
      * The MIME type for the desired output format.
@@ -321,7 +322,7 @@ public:
      *         Directory    = 2,
      *         Files        = 4,
      *         ExistingOnly = 8,
-     *         LocalOnly    = 16
+     *         LocalOnly    = 16,
      *    };
      * \endcode
      * You can OR the values, e.g.
@@ -532,14 +533,14 @@ protected:
 
 Q_SIGNALS:
     /**
-      * Emitted when the user selects a file. It is only emitted in single-
-      * selection mode. The best way to get notified about selected file(s)
-      * is to connect to the okClicked() signal inherited from KDialog
-      * and call selectedFile(), selectedFiles(),
-      * selectedUrl() or selectedUrls().
-      *
-      * \since 4.4
-      */
+     * Emitted when the user selects a file. It is only emitted in single-
+     * selection mode. The best way to get notified about selected file(s)
+     * is to connect to the okClicked() signal inherited from KDialog
+     * and call selectedFile(), selectedFiles(),
+     * selectedUrl() or selectedUrls().
+     *
+     * \since 4.4
+     */
     void fileSelected(const QUrl &);
 
     /**
@@ -592,29 +593,7 @@ public:
 
 private:
     friend class KFileWidgetPrivate;
-    KFileWidgetPrivate *const d;
-
-    Q_PRIVATE_SLOT(d, void _k_slotLocationChanged(const QString &))
-    Q_PRIVATE_SLOT(d, void _k_urlEntered(const QUrl &))
-    Q_PRIVATE_SLOT(d, void _k_enterUrl(const QUrl &))
-    Q_PRIVATE_SLOT(d, void _k_enterUrl(const QString &))
-    Q_PRIVATE_SLOT(d, void _k_locationAccepted(const QString &))
-    Q_PRIVATE_SLOT(d, void _k_slotFilterChanged())
-    Q_PRIVATE_SLOT(d, void _k_fileHighlighted(const KFileItem &))
-    Q_PRIVATE_SLOT(d, void _k_fileSelected(const KFileItem &))
-    Q_PRIVATE_SLOT(d, void _k_slotLoadingFinished())
-    Q_PRIVATE_SLOT(d, void _k_fileCompletion(const QString &))
-    Q_PRIVATE_SLOT(d, void _k_toggleSpeedbar(bool))
-    Q_PRIVATE_SLOT(d, void _k_toggleBookmarks(bool))
-    Q_PRIVATE_SLOT(d, void _k_slotAutoSelectExtClicked())
-    Q_PRIVATE_SLOT(d, void _k_placesViewSplitterMoved(int, int))
-    Q_PRIVATE_SLOT(d, void _k_activateUrlNavigator())
-    Q_PRIVATE_SLOT(d, void _k_zoomOutIconsSize())
-    Q_PRIVATE_SLOT(d, void _k_zoomInIconsSize())
-    Q_PRIVATE_SLOT(d, void _k_slotIconSizeSliderMoved(int))
-    Q_PRIVATE_SLOT(d, void _k_slotIconSizeChanged(int))
-    Q_PRIVATE_SLOT(d, void _k_slotViewDoubleClicked(const QModelIndex&))
-    Q_PRIVATE_SLOT(d, void _k_slotViewKeyEnterReturnPressed())
+    std::unique_ptr<KFileWidgetPrivate> const d;
 };
 
 #endif
