@@ -1,37 +1,29 @@
-/*****************************************************************************
- * Copyright (C) 2006-2010 by Peter Penz <peter.penz@gmx.at>                 *
- * Copyright (C) 2006 by Aaron J. Seigo <aseigo@kde.org>                     *
- * Copyright (C) 2007 by Kevin Ottens <ervin@kde.org>                        *
- * Copyright (C) 2007 by Urs Wolfer <uwolfer @ kde.org>                      *
- *                                                                           *
- * This library is free software; you can redistribute it and/or             *
- * modify it under the terms of the GNU Library General Public               *
- * License as published by the Free Software Foundation; either              *
- * version 2 of the License, or (at your option) any later version.          *
- *                                                                           *
- * This library is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
- * Library General Public License for more details.                          *
- *                                                                           *
- * You should have received a copy of the GNU Library General Public License *
- * along with this library; see the file COPYING.LIB.  If not, write to      *
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- * Boston, MA 02110-1301, USA.                                               *
- *****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006-2010 Peter Penz <peter.penz@gmx.at>
+    SPDX-FileCopyrightText: 2006 Aaron J. Seigo <aseigo@kde.org>
+    SPDX-FileCopyrightText: 2007 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2007 Urs Wolfer <uwolfer @ kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KURLNAVIGATOR_H
 #define KURLNAVIGATOR_H
 
 #include "kiofilewidgets_export.h"
 
+#include <QByteArray>
 #include <QUrl>
 #include <QWidget>
-#include <QByteArray>
+
+#include <memory>
+
+class QMouseEvent;
 
 class KFilePlacesModel;
 class KUrlComboBox;
-class QMouseEvent;
+
+class KUrlNavigatorPrivate;
 
 /**
  * @class KUrlNavigator kurlnavigator.h <KUrlNavigator>
@@ -500,21 +492,8 @@ protected:
 #endif
 
 private:
-    Q_PRIVATE_SLOT(d, void slotReturnPressed())
-    Q_PRIVATE_SLOT(d, void slotProtocolChanged(const QString &protocol))
-    Q_PRIVATE_SLOT(d, void slotToggleEditableButtonPressed())
-    Q_PRIVATE_SLOT(d, void dropUrls(const QUrl &destination, QDropEvent *))
-    Q_PRIVATE_SLOT(d, void slotNavigatorButtonClicked(const QUrl &url, Qt::MouseButton button, Qt::KeyboardModifiers modifiers))
-    Q_PRIVATE_SLOT(d, void openContextMenu(QPoint))
-    Q_PRIVATE_SLOT(d, void openPathSelectorMenu())
-    Q_PRIVATE_SLOT(d, void updateButtonVisibility())
-    Q_PRIVATE_SLOT(d, void switchToBreadcrumbMode())
-    Q_PRIVATE_SLOT(d, void slotPathBoxChanged(const QString &text))
-    Q_PRIVATE_SLOT(d, void updateContent())
-
-private:
-    class Private;
-    Private *const d;
+    friend class KUrlNavigatorPrivate;
+    std::unique_ptr<KUrlNavigatorPrivate> const d;
 
     Q_DISABLE_COPY(KUrlNavigator)
 };
