@@ -9,8 +9,8 @@
 
 #include <QAction>
 #include <QMenu>
-#include <QPainter>
 #include <QPaintEvent>
+#include <QPainter>
 #include <QStyleOption>
 
 #include <KLocalizedString>
@@ -25,15 +25,14 @@ const int ArrowSize = 10;
 
 namespace KDEPrivate
 {
-
-KUrlNavigatorProtocolCombo::KUrlNavigatorProtocolCombo(const QString &protocol, QWidget *parent) :
-    KUrlNavigatorButtonBase(parent),
-    m_menu(nullptr),
-    m_protocols(),
-    m_categories()
+KUrlNavigatorProtocolCombo::KUrlNavigatorProtocolCombo(const QString &protocol, KUrlNavigator *parent)
+    : KUrlNavigatorButtonBase(parent)
+    , m_menu(nullptr)
+    , m_protocols()
+    , m_categories()
 {
     m_menu = new QMenu(this);
-    connect(m_menu, &QMenu::triggered, this, QOverload<QAction*>::of(&KUrlNavigatorProtocolCombo::setProtocol));
+    connect(m_menu, &QMenu::triggered, this, &KUrlNavigatorProtocolCombo::setProtocolFromMenu);
     setText(protocol);
     setMenu(m_menu);
 }
@@ -96,7 +95,7 @@ void KUrlNavigatorProtocolCombo::paintEvent(QPaintEvent *event)
     Q_UNUSED(event);
 
     QPainter painter(this);
-    const int buttonWidth  = width();
+    const int buttonWidth = width();
     const int buttonHeight = height();
 
     drawHoverBackground(&painter);
@@ -122,15 +121,14 @@ void KUrlNavigatorProtocolCombo::paintEvent(QPaintEvent *event)
     if (!style()->styleHint(QStyle::SH_UnderlineShortcut, &option, this)) {
         alignment |= Qt::TextHideMnemonic;
     }
-    style()->drawItemText(&painter, QRect(BorderWidth, 0, textWidth, buttonHeight),
-                          alignment, option.palette, isEnabled(), text());
+    style()->drawItemText(&painter, QRect(BorderWidth, 0, textWidth, buttonHeight), alignment, option.palette, isEnabled(), text());
 }
 
-void KUrlNavigatorProtocolCombo::setProtocol(QAction *action)
+void KUrlNavigatorProtocolCombo::setProtocolFromMenu(QAction *action)
 {
     const QString protocol = action->data().toString();
     setText(protocol);
-    emit activated(protocol);
+    Q_EMIT activated(protocol);
 }
 
 void KUrlNavigatorProtocolCombo::updateMenu()
@@ -140,7 +138,7 @@ void KUrlNavigatorProtocolCombo::updateMenu()
 
     // move all protocols into the corresponding category of 'items'
     QList<QString> items[CategoryCount];
-    for (const QString &protocol : qAsConst(m_protocols)) {
+    for (const QString &protocol : std::as_const(m_protocols)) {
         if (m_categories.contains(protocol)) {
             const ProtocolCategory category = m_categories.value(protocol);
             items[category].append(protocol);
@@ -174,7 +172,7 @@ void KUrlNavigatorProtocolCombo::updateMenu()
                 break;
             }
 
-            for (const QString &protocol : qAsConst(items[category])) {
+            for (const QString &protocol : std::as_const(items[category])) {
                 QAction *action = menu->addAction(protocol);
                 action->setData(protocol);
             }
