@@ -43,8 +43,11 @@
 #include <QMimeDatabase>
 #include <QStandardPaths>
 #include <kprotocolinfo.h>
+#include <Solid/Device>
+#include <Solid/StorageAccess>
 
 #include <algorithm>
+#include <cmath>
 
 #include "job_p.h"
 
@@ -91,6 +94,7 @@ public:
         STATE_STATORIG, // if the thumbnail exists
         STATE_GETORIG, // if we create it
         STATE_CREATETHUMB, // thumbnail:/ slave
+        STATE_DEVICE_INFO, // additional state check to get needed device ids
     } state;
 
     KFileItemList initialItems;
@@ -136,13 +140,19 @@ public:
     int shmid;
     // And the data area
     uchar *shmaddr;
+    // Size of the shm segment
+    size_t shmsize;
     // Root of thumbnail cache
     QString thumbRoot;
-    // List of encrypted mount points for checking if we should save thumbnail
-    KMountPoint::List encryptedMountsList;
     // Metadata returned from the KIO thumbnail slave
     QMap<QString, QString> thumbnailSlaveMetaData;
     int devicePixelRatio = s_defaultDevicePixelRatio;
+    static const int idUnknown = -1;
+    // Id of a device storing currently processed file
+    int currentDeviceId = 0;
+    // Device ID for each file. Stored while in STATE_DEVICE_INFO state, used later on.
+    QMap<QString, int> deviceIdMap;
+    enum CachePolicy { Prevent, Allow, Unknown } currentDeviceCachePolicy = Unknown;
 
     void getOrCreateThumbnail();
     bool statResultThumbnail();
@@ -153,14 +163,24 @@ public:
 
     void startPreview();
     void slotThumbData(KIO::Job *, const QByteArray &);
+    // Checks if thumbnail is on encrypted partition different than thumbRoot
+    CachePolicy canBeCached(const QString &path);
+    int getDeviceId(const QString &path);
 
     Q_DECLARE_PUBLIC(PreviewJob)
 };
 
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 86)
 void PreviewJob::setDefaultDevicePixelRatio(int defaultDevicePixelRatio)
 {
     s_defaultDevicePixelRatio = defaultDevicePixelRatio;
 }
+#endif
+
+void PreviewJob::setDefaultDevicePixelRatio(qreal defaultDevicePixelRatio)
+{
+    s_defaultDevicePixelRatio = std::ceil(defaultDevicePixelRatio);
+}
 
 #if KIOWIDGETS_BUILD_DEPRECATED_SINCE(4, 7)
 PreviewJob::PreviewJob(const KFileItemList &items, int width, int height, int iconSize, int iconAlpha, bool scale, bool save, const QStringList *enabledPlugins)
@@ -275,7 +295,7 @@ void PreviewJobPrivate::startPreview()
         if (!p.isEmpty()) {
             protocols.append(p);
         }
-        for (const QString &protocol : qAsConst(protocols)) {
+        for (const QString &protocol : std::as_const(protocols)) {
             // We cannot use mimeTypes() here, it doesn't support groups such as: text/*
             const QStringList mtypes = (*it)->serviceTypes();
             // Add supported MIME type for this protocol
@@ -299,13 +319,6 @@ void PreviewJobPrivate::startPreview()
         }
     }
 
-    // Prepare encryptedMountsList which will be used in ::slotThumbData
-    const auto mountsList = KMountPoint::currentMountPoints();
-    const auto thumbRootMount = mountsList.findByPath(thumbRoot);
-    std::copy_if(mountsList.begin(), mountsList.end(), std::back_inserter(encryptedMountsList), [&thumbRootMount](KMountPoint::Ptr mount) {
-        return (thumbRootMount != mount) && (mount->mountType() == QLatin1String("fuse.cryfs") || mount->mountType() == QLatin1String("fuse.encfs"));
-    });
-
     // Look for images and store the items in our todo list :)
     bool bNeedCache = false;
     KFileItemList::const_iterator kit = initialItems.constBegin();
@@ -458,10 +471,17 @@ bool KIO::PreviewJob::handlesSequences() const
     return d_func()->thumbnailSlaveMetaData.value(QStringLiteral("handlesSequences")) == QStringLiteral("1");
 }
 
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 86)
 void KIO::PreviewJob::setDevicePixelRatio(int dpr)
 {
     d_func()->devicePixelRatio = dpr;
 }
+#endif
+
+void KIO::PreviewJob::setDevicePixelRatio(qreal dpr)
+{
+    d_func()->devicePixelRatio = std::ceil(dpr);
+}
 
 void PreviewJob::setIgnoreMaximumSize(bool ignoreSize)
 {
@@ -495,7 +515,7 @@ void PreviewJobPrivate::determineNextFile()
         currentItem = items.front();
         items.pop_front();
         succeeded = false;
-        KIO::Job *job = KIO::stat(currentItem.item.url(), KIO::HideProgressInfo);
+        KIO::Job *job = KIO::statDetails(currentItem.item.url(), StatJob::SourceSide, KIO::StatDefaultDetails | KIO::StatInode, KIO::HideProgressInfo);
         job->addMetaData(QStringLiteral("thumbnail"), QStringLiteral("1"));
         job->addMetaData(QStringLiteral("no-auth-prompt"), QStringLiteral("true"));
         q->addSubjob(job);
@@ -515,11 +535,12 @@ void PreviewJob::slotResult(KJob *job)
             d->determineNextFile();
             return;
         }
-        const KIO::UDSEntry entry = static_cast<KIO::StatJob *>(job)->statResult();
-        d->tOrig = QDateTime::fromSecsSinceEpoch(entry.numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME, 0));
+        const KIO::UDSEntry statResult = static_cast<KIO::StatJob *>(job)->statResult();
+        d->currentDeviceId = statResult.numberValue(KIO::UDSEntry::UDS_DEVICE_ID, 0);
+        d->tOrig = QDateTime::fromSecsSinceEpoch(statResult.numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME, 0));
 
         bool skipCurrentItem = false;
-        const KIO::filesize_t size = (KIO::filesize_t)entry.numberValue(KIO::UDSEntry::UDS_SIZE, 0);
+        const KIO::filesize_t size = (KIO::filesize_t)statResult.numberValue(KIO::UDSEntry::UDS_SIZE, 0);
         const QUrl itemUrl = d->currentItem.item.mostLocalUrl();
 
         if (itemUrl.isLocalFile() || KProtocolInfo::protocolClass(itemUrl.scheme()) == QLatin1String(":local")) {
@@ -558,6 +579,21 @@ void PreviewJob::slotResult(KJob *job)
         d->getOrCreateThumbnail();
         return;
     }
+    case PreviewJobPrivate::STATE_DEVICE_INFO: {
+        KIO::StatJob *statJob = static_cast<KIO::StatJob *>(job);
+        int id;
+        QString path = statJob->url().toLocalFile();
+        if (job->error()) {
+            // We set id to 0 to know we tried getting it
+            qCWarning(KIO_WIDGETS) << "Cannot read information about filesystem under path" << path;
+            id = 0;
+        } else {
+            id = statJob->statResult().numberValue(KIO::UDSEntry::UDS_DEVICE_ID, 0);
+        }
+        d->deviceIdMap[path] = id;
+        d->createThumbnail(d->currentItem.item.localPath());
+        return;
+    }
     case PreviewJobPrivate::STATE_GETORIG: {
         if (job->error()) {
             d->cleanupTempFile();
@@ -618,9 +654,9 @@ bool PreviewJobPrivate::statResultThumbnail()
         return false;
     }
 
-    if (thumb.width() == width * devicePixelRatio || thumb.height() == height * devicePixelRatio) {
-        thumb.setDevicePixelRatio(devicePixelRatio);
-    }
+    // The DPR of the loaded thumbnail is unspecified (and typically irrelevant).
+    // When a thumbnail is DPR-invariant, use the DPR passed in the request.
+    thumb.setDevicePixelRatio(devicePixelRatio);
 
     QString thumbnailerVersion = currentItem.plugin->property(QStringLiteral("ThumbnailerVersion"), QVariant::String).toString();
 
@@ -698,6 +734,71 @@ void PreviewJobPrivate::getOrCreateThumbnail()
     }
 }
 
+PreviewJobPrivate::CachePolicy PreviewJobPrivate::canBeCached(const QString &path)
+{
+    // If checked file is directory on a different filesystem than its parent, we need to check it separately
+    int separatorIndex = path.lastIndexOf(QLatin1Char('/'));
+    QString parentDirPath = path.left(separatorIndex);
+
+    int parentId = getDeviceId(parentDirPath);
+    if (parentId == idUnknown) {
+        return CachePolicy::Unknown;
+    }
+
+    bool isDifferentSystem = !parentId || parentId != currentDeviceId;
+    if (!isDifferentSystem && currentDeviceCachePolicy != CachePolicy::Unknown) {
+        return currentDeviceCachePolicy;
+    }
+    int checkedId;
+    QString checkedPath;
+    if (isDifferentSystem) {
+        checkedId = currentDeviceId;
+        checkedPath = path;
+    } else {
+        checkedId = getDeviceId(parentDirPath);
+        checkedPath = parentDirPath;
+        if (checkedId == idUnknown) {
+            return CachePolicy::Unknown;
+        }
+    }
+    // If we're checking different filesystem or haven't checked yet see if filesystem matches thumbRoot
+    int thumbRootId = getDeviceId(thumbRoot);
+    if (thumbRootId == idUnknown) {
+        return CachePolicy::Unknown;
+    }
+    bool shouldAllow = checkedId && checkedId == thumbRootId;
+    if (!shouldAllow) {
+        Solid::Device device = Solid::Device::storageAccessFromPath(checkedPath);
+        if (device.isValid()) {
+            shouldAllow = !device.as<Solid::StorageAccess>()->isEncrypted();
+        }
+    }
+    if (!isDifferentSystem) {
+        currentDeviceCachePolicy = shouldAllow ? CachePolicy::Allow : CachePolicy::Prevent;
+    }
+    return shouldAllow ? CachePolicy::Allow : CachePolicy::Prevent;
+}
+
+int PreviewJobPrivate::getDeviceId(const QString &path)
+{
+    Q_Q(PreviewJob);
+    auto iter = deviceIdMap.find(path);
+    if (iter != deviceIdMap.end()) {
+        return iter.value();
+    }
+    QUrl url = QUrl::fromLocalFile(path);
+    if (!url.isValid()) {
+        qCWarning(KIO_WIDGETS) << "Invalid url" << path;
+        return 0;
+    }
+    state = PreviewJobPrivate::STATE_DEVICE_INFO;
+    KIO::Job *job = KIO::statDetails(url, StatJob::SourceSide, KIO::StatDefaultDetails | KIO::StatInode, KIO::HideProgressInfo);
+    job->addMetaData(QStringLiteral("no-auth-prompt"), QStringLiteral("true"));
+    q->addSubjob(job);
+
+    return idUnknown;
+}
+
 void PreviewJobPrivate::createThumbnail(const QString &pixPath)
 {
     Q_Q(PreviewJob);
@@ -705,13 +806,23 @@ void PreviewJobPrivate::createThumbnail(const QString &pixPath)
     QUrl thumbURL;
     thumbURL.setScheme(QStringLiteral("thumbnail"));
     thumbURL.setPath(pixPath);
+
+    bool save = bSave && currentItem.plugin->property(QStringLiteral("CacheThumbnail")).toBool() && !sequenceIndex;
+
+    bool isRemoteProtocol = currentItem.item.localPath().isEmpty();
+    CachePolicy cachePolicy = isRemoteProtocol ? CachePolicy::Prevent : canBeCached(pixPath);
+
+    if (cachePolicy == CachePolicy::Unknown) {
+        // If Unknown is returned, creating thumbnail should be called again by slotResult
+        return;
+    }
+
     KIO::TransferJob *job = KIO::get(thumbURL, NoReload, HideProgressInfo);
     q->addSubjob(job);
     q->connect(job, &KIO::TransferJob::data, q, [this](KIO::Job *job, const QByteArray &data) {
         slotThumbData(job, data);
     });
 
-    bool save = bSave && currentItem.plugin->property(QStringLiteral("CacheThumbnail")).toBool() && !sequenceIndex;
     int thumb_width = width;
     int thumb_height = height;
     int thumb_iconSize = iconSize;
@@ -728,22 +839,25 @@ void PreviewJobPrivate::createThumbnail(const QString &pixPath)
     job->addMetaData(QStringLiteral("plugin"), currentItem.plugin->library());
     job->addMetaData(QStringLiteral("enabledPlugins"), enabledPlugins.join(QLatin1Char(',')));
     job->addMetaData(QStringLiteral("devicePixelRatio"), QString::number(devicePixelRatio));
+    job->addMetaData(QStringLiteral("cache"), QString::number(cachePolicy == CachePolicy::Allow));
     if (sequenceIndex) {
         job->addMetaData(QStringLiteral("sequence-index"), QString::number(sequenceIndex));
     }
 
 #if WITH_SHM
-    if (shmid == -1) {
+    size_t requiredSize = thumb_width * devicePixelRatio * thumb_height * devicePixelRatio * 4;
+    if (shmid == -1 || shmsize < requiredSize) {
         if (shmaddr) {
             // clean previous shared memory segment
             shmdt((char *)shmaddr);
-            shmctl(shmid, IPC_RMID, nullptr);
             shmaddr = nullptr;
+            shmctl(shmid, IPC_RMID, nullptr);
+            shmid = -1;
         }
-        auto size = thumb_width * thumb_height;
-        if (size > 0) {
-            shmid = shmget(IPC_PRIVATE, size * 4 * devicePixelRatio * devicePixelRatio, IPC_CREAT | 0600);
+        if (requiredSize > 0) {
+            shmid = shmget(IPC_PRIVATE, requiredSize, IPC_CREAT | 0600);
             if (shmid != -1) {
+                shmsize = requiredSize;
                 shmaddr = (uchar *)(shmat(shmid, nullptr, SHM_RDONLY));
                 if (shmaddr == (uchar *)-1) {
                     shmctl(shmid, IPC_RMID, nullptr);
@@ -762,11 +876,10 @@ void PreviewJobPrivate::createThumbnail(const QString &pixPath)
 void PreviewJobPrivate::slotThumbData(KIO::Job *job, const QByteArray &data)
 {
     thumbnailSlaveMetaData = job->metaData();
-    const bool isEncrypted = encryptedMountsList.findByPath(currentItem.item.url().toLocalFile());
     /* clang-format off */
     const bool save = bSave
                       && !sequenceIndex
-                      && !isEncrypted
+                      && currentDeviceCachePolicy == CachePolicy::Allow
                       && currentItem.plugin->property(QStringLiteral("CacheThumbnail")).toBool()
                       && (!currentItem.item.url().isLocalFile()
                           || !currentItem.item.url().adjusted(QUrl::RemoveFilename).toLocalFile().startsWith(thumbRoot));
@@ -777,7 +890,8 @@ void PreviewJobPrivate::slotThumbData(KIO::Job *job, const QByteArray &data)
     if (shmaddr) {
         // Keep this in sync with kdebase/kioslave/thumbnail.cpp
         QDataStream str(data);
-        int width, height;
+        int width;
+        int height;
         quint8 iFormat;
         int imgDevicePixelRatio = 1;
         // TODO KF6: add a version number as first parameter
@@ -790,9 +904,12 @@ void PreviewJobPrivate::slotThumbData(KIO::Job *job, const QByteArray &data)
         QImage::Format format = static_cast<QImage::Format>(iFormat);
         thumb = QImage(shmaddr, width, height, format).copy();
         thumb.setDevicePixelRatio(imgDevicePixelRatio);
-    } else
-#endif
+    } else {
         thumb.loadFromData(data);
+    }
+#else
+    thumb.loadFromData(data);
+#endif
 
     if (thumb.isNull()) {
         QDataStream s(data);
